#!/bin/bash

# define here user directory where RunMC will be installed
# User directory will be $RUNMC_USER/runmc 
RUNMC_USER=$HOME

# assume that RunMC was installed to  
# $RUNMC_DIR/RunMC
RUNMC_DIR="/usr/local"


# ------------------- do not modify anything below ----------------


if [ -z $RUNMC ]
then
  echo "* ok, \$RUNMC is not set."
else
  echo "\$RUNMC enviromental  variable was set!";
  echo "You should remove it from .bashrc or .cshrc";
  echo "then run this script again";
  exit 1;
fi



CURRENT_DIR=`pwd`

# get $RUNMC variable (assume current direcory)
LL=`expr length "$CURRENT_DIR"`
LL=`expr $LL-6`
RUNMC=${RUNMC:0:$LL}

# chech ROOT permiss
ROOT_UID=0         # Root has $UID 0.
# This script must be run as root.
if [ "$UID" -eq "$ROOT_UID" ]
then
  echo; echo "You must be user, not root, to run this script.";
  exit 1;
fi


# installation directory
RUNMCDIR=$RUNMC_DIR"/RunMC"

# user directory
RUNMCUSER=$RUNMC_USER"/runmc"

echo " "
echo " "
echo "                --- RunMC Toolkit User Installation  ---"
echo " "
echo " "


FCHECK=$RUNMC 
if [ -z $FCHECK ]
then
  echo "\$RUNMC is not set!  Stop installation"
  exit 1;
else
  echo "* ok, \$RUNMC set to $FCHECK";
fi


echo " * ok, $RUNMCDIR  is used for the installation";
echo " * ok, $RUNMCUSER is used for user directory ";

echo " "
echo -n "Do you wish to proceed [y or n] :"
read ANS
   case $ANS in
   y|Y|yes|Yes) echo "Yes is selected"
   ;;
   n|N) echo "No is selected" 
   exit 0
   ;;
   *) echo "`basename $0` : Unknown response" >&2
   exit 1
   ;;
 esac 
 
# check installation directory
if test -e $RUNMCDIR;
then
    echo " * ok, $RUNMCDIR found"
    echo "       RunMC will be installed to this directory"
else
     echo " ERROR: $RUNMCDIR is not found" 
     exit 0; 
fi

# check user directory
if test -e $RUNMCUSER;
then
    echo " * ok, $RUNMCUSER found"
    echo "       user files will be installed to this directory"
else
    echo " * ok, "; mkdir -v $RUNMCUSER
    echo "        user files will be installed to this directory"
fi


# check install directory
FCHECK=`ls $RUNMCDIR`; 
LL=`expr length "$FCHECK"`
if (("$LL" == 0));
then 
    echo "ERROR: $RUNMCDIR is empty!"
    echo "Did you install RunMC to $RUNMCDIR ?"
    exit 1;
fi

# check user directory
FCHECK=`ls $RUNMCUSER`;
LL=`expr length "$FCHECK"`
if (("$LL" > 1));
then 
    echo "ERROR: $RUNMCUSER is not empty!"  
    echo "Tip:   remove all files in $RUNMCUSER manually and start this script again!"
    exit 1;
else 
# create user files
    echo " * ok, wait! User directories are copied to $RUNMCUSER"
    cp -r $RUNMCDIR"/proj"    $RUNMCUSER
    cp -r $RUNMCDIR"/archive" $RUNMCUSER
    cp -r $RUNMCDIR"/bin"     $RUNMCUSER
    cp -r $RUNMCDIR"/pipes"   $RUNMCUSER
    ln -s $RUNMCDIR"/main"    $RUNMCUSER/"main"
    ln -s $RUNMCDIR"/doc"     $RUNMCUSER/"doc"
    ln -s $RUNMCDIR"/example" $RUNMCUSER/"example"
    ln -s $RUNMCDIR"/build"   $RUNMCUSER/"build"
fi

# change this
echo "Open .bashrc and include the lines:" 
echo "         export RUNMC=$RUNMCUSER"
echo "         export PATH=\$RUNMC/bin:\$PATH" 
echo "         export LD_LIBRARY_PATH=\$RUNMC/main/lib:\$LD_LIBRARY_PATH"
echo "then open new window, go to $RUNMC/proj  and type runmc" 
exit 0

