*CMZ :  6.21/20 16/12/2002  23.59.02  by  Unknown
*-- Author :
      SUBROUTINE GPYCHA

*#**********************************************************************
*#
*#    SUBROUTINE GPYCHA
*#
*# PURPOSE: Interpret the BOS text bank GPYT to change the default
*#          parameters of PYTHIA 6.1.
*#          note: only those parameters can be changed which the user
*#                may change according to the PYTHIA manual.
*#
*# INPUT: Bos text bank GPYT
*#
*# OUTPUT: updated parameters in PYTHIA commons.
*#
*# CALLED BY: GPYTHI
*#
*# CHANGED BY: B. Andrieu                                 DATE: 25/04/00
*# REASON: Adaptation to PYTHIA 6.1
*#           -> conversion to double precision
*#           -> merging PYTHIA/JETSET : only one text bank read (GPYT)
*#         Replacement of COMMONs by +SEQs.
*#
*# CHANGED BY: B. Andrieu                                 DATE: 22/05/01
*# REASON: Implementation of MSSM parameters (done by W. Erdmann)
*#
*#**********************************************************************

#include "h1mcutil/comdef/cbcs.inc"

*KEEP,h1beam.
C---additional PYTHIA commons (not part of standard PYTHIA)
      CHARACTER*8     FRAME,BEAM,TARGET
      COMMON /PBEAM1/ FRAME,BEAM,TARGET
      SAVE /PBEAM1/
      real * 8        win,pbeam,ptarge
      COMMON /PBEAM2/ WIN,PBEAM(3),PTARGE(3)
      SAVE /PBEAM2/
*KEEP,pydat.
      PARAMETER (NKC=500)
*KEEP,pysub.
      PARAMETER (NSUB=500,NKF=40)
*KEEP,pysubs.
      PARAMETER (NBT=2,NCKIN=200)
      COMMON/PYSUBS/MSEL,MSELPD,
     +              MSUB(NSUB),KFIN(NBT,-NKF:NKF),CKIN(NCKIN)
      REAL *8 ckin
      SAVE /PYSUBS/
*KEEP,pypars.
      PARAMETER (NMSTP=200,NPARP=200,NMSTI=200,NPARI=200)
      COMMON/PYPARS/MSTP(NMSTP),PARP(NPARP),MSTI(NMSTI),PARI(NPARI)
      REAL *8 parp,pari
      SAVE /PYPARS/
#include "rgludat1.inc"
#include "rgludat2.inc"
#include "rgludat3.inc"
*KEEP,pymssm.
      PARAMETER (NIMSS=99,NRMSS=99)
      COMMON/PYMSSM/IMSS(0:NIMSS),RMSS(0:NRMSS)
      real*8 RMSS
      SAVE /PYMSSM/
*KEND.

      CHARACTER*4     CHAINT,PARAM

C---Is there a text bank to be interpreted
      IND = NLINK('GPYT',0)
      IF (IND.LE.0) THEN
         PRINT *,' GPYCHA: GPYT BANK NOT FOUND,',
     &           ' NO PYTHIA PARAMETERS CHANGED'
         GOTO 500
      ELSE
         PRINT *,' GPYCHA: GPYT BANK EXISTS,',
     &           ' PYTHIA PARAMETERS MIGHT BE CHANGED'
      ENDIF

C---Determine the machine accuacy EPSMAC (D= 2.E-06)
      EPSMAC = 0.5
      DO 33 I= 1, 100
      EPSMAC = EPSMAC * 0.5
      IF ((1.0+EPSMAC) .EQ. 1.0)  GO TO 35
   33 CONTINUE
      EPSMAC = 1.0E-6
   35 EPSMAC = 2.0 * EPSMAC
      WRITE(6,330) EPSMAC
 330  FORMAT(1X,/,' COMPUTED MACHINE ACCURACY = ',G10.2,/)

C---Interpret the text bank containing the parameters to be changed
      IF (IW(IND).NE.0) THEN
         DO 100,I=IND+4,IND+IW(IND),4

            PARAM = CHAINT(IW(I-3))
            LND = IW(I-2)
            LNE = IW(I-1)
            INT = IW(I)
            REA = RW(I)

C--- PBEAM1
            IF (PARAM.EQ.'FRAM') THEN
                PRINT 1010, PARAM,FRAME(1:4),FRAME(5:8)
                FRAME(1:4) = CHAINT(IW(I-1))
                FRAME(5:8) = CHAINT(IW(I))
                PRINT 1011, FRAME(1:4),FRAME(5:8)
            ENDIF

            IF (PARAM.EQ.'BEAM') THEN
                PRINT 1010, PARAM,BEAM(1:4),BEAM(5:8)
                BEAM(1:4) = CHAINT(IW(I-1))
                BEAM(5:8) = CHAINT(IW(I))
                PRINT 1011, BEAM(1:4),BEAM(5:8)
            ENDIF

            IF (PARAM.EQ.'TARG') THEN
                PRINT 1010, PARAM,TARGET(1:4),TARGET(5:8)
                TARGET(1:4) = CHAINT(IW(I-1))
                TARGET(5:8) = CHAINT(IW(I))
                PRINT 1011, TARGET(1:4),TARGET(5:8)
            ENDIF

C--- PBEAM2
            IF (PARAM.EQ.'WIN ') THEN
                RDEF = sngl(WIN)
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    WIN = dble(REA)
                    PRINT 1002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 2002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PBEA') THEN
                RDEF = sngl(PBEAM(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PBEAM(LND) = dble(REA)
                    PRINT 1002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 2002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PTAR') THEN
                RDEF = sngl(PTARGE(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PTARGE(LND) = dble(REA)
                    PRINT 1002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 2002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

C--- PYSUBS
            IF (PARAM.EQ.'MSEL') THEN
                IDEF = MSEL
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MSEL = INT
                    PRINT 1001, PARAM,LND,IDEF,INT
                ELSE
                    PRINT 2001, PARAM,LND,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'MSUB') THEN
                IDEF = MSUB(LND)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MSUB(LND) = INT
                    PRINT 1001, PARAM,LND,IDEF,INT
                ELSE
                    PRINT 2001, PARAM,LND,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'KFIN') THEN
                IDEF = KFIN(LND,LNE)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    KFIN(LND,LNE) = INT
                    PRINT 1003, PARAM,LND,LNE,IDEF,INT
                ELSE
                    PRINT 2003, PARAM,LND,LNE,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'CKIN') THEN
                RDEF = sngl(CKIN(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    CKIN(LND) = dble(REA)
                    PRINT 1002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 2002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

C--- PYPARS
            IF (PARAM.EQ.'MSTP') THEN
                IDEF = MSTP(LND)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MSTP(LND) = INT
                    PRINT 1001, PARAM,LND,IDEF,INT
                ELSE
                    PRINT 2001, PARAM,LND,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PARP') THEN
                RDEF = sngl(PARP(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PARP(LND) = dble (REA)
                    PRINT 1002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 2002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

C--- PYDAT1
            IF (PARAM.EQ.'MSTU') THEN
                IDEF = MSTU(LND)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MSTU(LND) = INT
                    PRINT 91001, PARAM,LND,IDEF,INT
                ELSE
                    PRINT 92001, PARAM,LND,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PARU') THEN
                RDEF = sngl(PARU(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PARU(LND) = dble(REA)
                    PRINT 91002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 92002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

            IF (PARAM.EQ.'MSTJ') THEN
                IDEF = MSTJ(LND)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MSTJ(LND) = INT
                    PRINT 91001, PARAM,LND,IDEF,INT
                ELSE
                    PRINT 92001, PARAM,LND,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PARJ') THEN
                RDEF = sngl(PARJ(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PARJ(LND)= dble(REA)
                    PRINT 91002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 92002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

C--- PYDAT2
            IF (PARAM.EQ.'KCHG') THEN
                IDEF = KCHG(LND,LNE)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    KCHG(LND,LNE) = INT
                    PRINT 91003, PARAM,LND,LNE,IDEF,INT
                ELSE
                    PRINT 92003, PARAM,LND,LNE,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PMAS') THEN
                RDEF = sngl(PMAS(LND,LNE))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PMAS(LND,LNE)=dble(REA)
                    PRINT 91004, PARAM,LND,LNE,RDEF,REA
                ELSE
                    PRINT 92004, PARAM,LND,LNE,RDEF,REA
                ENDIF
            ENDIF

            IF (PARAM.EQ.'PARF') THEN
                RDEF = sngl(PARF(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    PARF(LND) = dble(REA)
                    PRINT 91002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 92002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

            IF (PARAM.EQ.'VCKM') THEN
                RDEF = sngl(VCKM(LND,LNE))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    VCKM(LND,LNE) = dble(REA)
                    PRINT 91004, PARAM,LND,LNE,RDEF,REA
                ELSE
                    PRINT 92004, PARAM,LND,LNE,RDEF,REA
                ENDIF
            ENDIF

C--- PYDAT3
            IF (PARAM.EQ.'MDCY') THEN
                IDEF = MDCY(LND,LNE)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MDCY(LND,LNE) = INT
                    PRINT 91003, PARAM,LND,LNE,IDEF,INT
                ELSE
                    PRINT 92003, PARAM,LND,LNE,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'MDME') THEN
                IDEF = MDME(LND,LNE)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    MDME(LND,LNE) = INT
                    PRINT 91003, PARAM,LND,LNE,IDEF,INT
                ELSE
                    PRINT 92003, PARAM,LND,LNE,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'BRAT') THEN
                RDEF = sngl(BRAT(LND))
                IF (ABS(RDEF-REA).GT.EPSMAC) THEN
                    BRAT(LND) = dble(REA)
                    PRINT 91002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 92002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

            IF (PARAM.EQ.'KFDP') THEN
                IDEF = KFDP(LND,LNE)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    KFDP(LND,LNE) = INT
                    PRINT 91003, PARAM,LND,LNE,IDEF,INT
                ELSE
                    PRINT 92003, PARAM,LND,LNE,IDEF,INT
                ENDIF
            ENDIF

C--- PYMSSM
            IF (PARAM.EQ.'IMSS') THEN
                IDEF = IMSS(LND)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    IMSS(LND) = INT
                    PRINT 91001, PARAM,LND,IDEF,INT
                ELSE
                    PRINT 92001, PARAM,LND,IDEF,INT
                ENDIF
            ENDIF

            IF (PARAM.EQ.'RMSS') THEN
                RDEF = RMSS(LND)
                IF (ABS(IDEF-INT).GT.EPSMAC) THEN
                    RMSS(LND) = dble(REA)
                    PRINT 91002, PARAM,LND,RDEF,REA
                ELSE
                    PRINT 92002, PARAM,LND,RDEF,REA
                ENDIF
            ENDIF

  100 CONTINUE
      ENDIF

91001 FORMAT(' GPYCHA:',A4,'(',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',I8,' TO',I8)
92001 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',I8,' TO',I8)
91002 FORMAT(' GPYCHA:',A4,'(',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',E10.3,' TO',E10.3)
92002 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',E10.3,' TO',E10.3)

91003 FORMAT(' GPYCHA:',A4,'(',I4,',',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',I8,' TO',I8)
92003 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,',',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',I8,' TO',I8)
91004 FORMAT(' GPYCHA:',A4,'(',I4,',',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',E10.3,' TO',E10.3)
92004 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,',',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',E10.3,' TO',E10.3)

91013 FORMAT(' GPYCHA:',
     &'CHAF(',I4,')    CHA. FROM DEFAULT:',A4,A4)
91014 FORMAT('                                     TO:',A4,A4)


 1001 FORMAT(' GPYCHA:',A4,'(',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',I8,' TO',I8)
 2001 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',I8,' TO',I8)
 1002 FORMAT(' GPYCHA:',A4,'(',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',E10.3,' TO',E10.3)
 2002 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',E10.3,' TO',E10.3)

 1003 FORMAT(' GPYCHA:',A4,'(',I4,',',I4,')',
     &       ' CHANGED FROM THE DEFAULT ',I8,' TO',I8)
 2003 FORMAT(' GPYCHA (WARNING):',A4,'(',I4,',',I4,')',
     &       ' NOT CHANGED FROM THE DEFAULT ',I8,' TO',I8)
 1010 FORMAT(' GPYCHA:',
     &       A4,' CHANGED FROM DEFAULT: ',A4,A4)
 1011 FORMAT ('                   TO: ',A4,A4)

  500 CONTINUE
      RETURN
      END
