*CMZ :  2.03/00 11/06/2002  17.37.29  by  Guenter Grindhammer
*CMZ :  1.00/00 21/08/92  17.36.53  by  Guenter Grindhammer
*-- Author :    Stephan Egli   09/06/91

      SUBROUTINE GTRGVX

*#**********************************************************************
*#
*#    SUBROUTINE GTRGVX
*#
*# PURPOSE: Add information about secondary vertices to GTR and GVX
*#          If the GVX bank contains already
*#          more than the primary vertex nothing will be done.
*#
*# CALLED BY: GENOUT
*#
*# INPUT:  GTR_ and GVX_ bank
*#
*# OUTPUT: modified GTR_ and GVX_ bank
*#
*# CHANGED BY: Wolfram Erdmann                            DATE: DD/08/01
*# REASON: take vertex information from the hepevt common as filled by
*#         the respective mc generator and fill gvx_ bank and make
*#         pointers from the gtr_ to the gvx_ bank. vertices from pi0
*#         decays are ignored.
*#
*# CHANGED BY: Guenter Grindhammer                        DATE: 01/10/03
*# REASON: include bug-fix for rapgap-resolved
*#
*#**********************************************************************

*KEEP,CBCS.
      INTEGER         NBOSIW
      PARAMETER       (NBOSIW=1000)
      INTEGER         IW(NBOSIW)
      REAL            RW(NBOSIW)
      COMMON /BCS/    IW
      EQUIVALENCE     (IW(1),RW(1))
      SAVE   /BCS/

#include "hepevt.inc"

* LINDEC is a parallel column to GTR bank with pointers to decay points
* in GVX bank

      COMMON/H1WORK/LINDEC(1000)
      DIMENSION ARR(5),IARR(5)
      EQUIVALENCE (ARR(1),IARR(1))

      DIMENSION II(20)
      INTEGER GEN

*+SEQ,STFUNCT.
*    /h1util/h1util_macros/bosmac
*     index of element before row number IROW
      INDR(IND,IROW)=IND+2+IW(IND+1)*(IROW-1)
*     index of L'th element  of row number IROW
      INDCR(IND,L,IROW)=INDR(IND,IROW) + L
*     L'th integer element of the IROW'th row of bank with index IND
      IBTAB(IND,L,IROW)=IW(INDCR(IND,L,IROW))
*     L'th real element of the IROW'th row of bank with index IND
      RBTAB(IND,L,IROW)=RW(INDCR(IND,L,IROW))

      numGTR = 1
      INV=0

c$$$      call hepdump(6)
c$$$      write(6,*)'GTRGVX> starting'
* loop over all entries in GTR bank

      INDGTR=IW(NAMIND('GTR '))
      IF(INDGTR.EQ.0)RETURN
      INDGVX=IW(NAMIND('GVX '))
      IF(INDGVX.EQ.0)RETURN

*     already secondary vertices existing ?
      IF(IW(INDGVX+2).GT.1)RETURN

      NTR=IW(INDGTR+2)

c     first pass, find decays with detached vertices -> make GVX
      DO ITR=1,NTR

cc      if(     (jdahep(1,ITR).GT.0)
cc   &     .and.(idhep(ITR).ne.111)  )  ! skip pi0
        if(     (jdahep(1,ITR).GT.0).and. (iabs(jdahep(1,ITR)).LT.NTR)
     &     .and.(idhep(ITR).ne.111)  )  ! skip bad pointer and skip pi0
     &  then

            deltat=vhep(4,jdahep(1,ITR))-vhep(4,ITR)
            if(deltat.gt.1.D-15)then
c              new vertex, make a new GVX entry
               numGTR=numGTR+1
c              vertex position   GVX [cm] = hepevt[mm] * 0.1cm/mm
               ARR(1)=sngl(vhep(1,jdahep(1,ITR))*0.1D0)
               ARR(2)=sngl(vhep(2,jdahep(1,ITR))*0.1D0)
               ARR(3)=sngl(vhep(3,jdahep(1,ITR))*0.1D0)
               IARR(4)=2
c              vertex time       GVX [s] = hepevt[mm/c] / c[mm/s]
               ARR(5)=sngl(vhep(4,jdahep(1,ITR))/2.99792D11)
               INV =IADROW('GVX ',0,5,ARR)
c              * fill GTR -> GVX pointers for all daughters of ITR
               do k=JDAhep(1,ITR), JDAhep(2,ITR)
                  if(JMOHEP(1,k).eq.ITR)then
                     IW( INDR(INDGTR,k) + 10 )=numGTR
                  endif
               enddo
             endif

         endif

      enddo

c     second pass, fill remaining GTR->GVX pointers

      DO 10 ITR=1,NTR

         IN = INDR(INDGTR,ITR)

c        do nothing if a decay vertex has been assigend in the first pass
         IF( IW(IN+10).GT.1 ) GOTO 10

c        * if no mother, call it primary
         IF( JMOHEP(1,ITR).eq.0 )then

               IW(IN+10) = 1

c        * mother has a valid GTR->GVX pointer =>copy it
         ELSE if( JMOHEP(1,ITR).LT.ITR )then

               IW(IN+10) = IW( INDR(INDGTR, JMOHEP(1,ITR)) + 10)

c        * mother/daughter out of sequence, find mother's mother etc
         ELSE

            gen=1
            II(GEN)=JMOHEP(1,ITR)

c           climb up the family tree until you find a known vertex
 40            continue
               GEN=GEN+1
               II(GEN)=JMOHEP(1,II(GEN-1))
               IF(.NOT.(     (II(GEN).LT.ITR)
     +                   .OR.(II(GEN).EQ.0)
     +                   .OR.(IW( INDR(INDGTR, II(GEN))+10).GT.1)  )
     +            ) GOTO 40

               IF(II(GEN).EQ.0) THEN
                  GEN=GEN-1
                  IW( INDR(INDGTR, II(GEN))+10 ) = 1
               ENDIF

 50            continue
               GEN=GEN-1
               IW( INDR(INDGTR, II(GEN  ))+10 ) =
     +         IW( INDR(INDGTR, II(GEN+1))+10 )
               IF (GEN.GT.1)goto 50

         ENDIF

 10   CONTINUE

      IF (INV .NE. 0) IND=IADFIN('GVX',0)
      RETURN
      END
