// * This code is licensed under:
// * RunMC License, Version 1.0
// * - for license details see http://runmc.sourceforge.net/License.txt
// *
// * Copyright (c) 2005 by S.Chekanov (chekanov@mail.desy.de).
// * All rights reserved.

using namespace std;
#include <TROOT.h>


#ifdef  PYTHIA57 
 #include "hepevt_pythia57.h"
#endif

#ifdef  PYTHIA6
  #include "hepevt_pythia62.h"
#endif

#include<hepevt_local.h>
#include<hepevt_runmc.h>
#include<heplist.h> 
#include<math.h>
#include<iostream>

#include<SetIni.h> // include class containing initializations for MC
extern SetIni inival;
// to define charge
extern Int_t charge3(Int_t pid);

// ---------------- Fill local common for simplified HEiPEVT output -------------------------------
hepenvtlocal  hlo; // to get local HEPEVT for output
hepenvtrunmc  rlo; // to get local RunMC for output


//-------------------------- Start 
Int_t hepevt_local() {

  extern hepenvtcommon hepevt_ ; // To access the external HEPEVT


  hlo.NEVHEP = hepevt_.NEVHEP;
  hlo.NHEP = hepevt_.NHEP;
         for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {
  hlo.ISTHEP[nn]=hepevt_.ISTHEP[nn];
  hlo.IDHEP[nn]=hepevt_.IDHEP[nn];
  hlo.JMOHEP1[nn]=hepevt_.JMOHEP[nn][0];
  hlo.JMOHEP2[nn]=hepevt_.JMOHEP[nn][1];
  hlo.JDAHEP1[nn]=hepevt_.JDAHEP[nn][0];
  hlo.JDAHEP2[nn]=hepevt_.JDAHEP[nn][1];
  hlo.CHA3[nn]=charge3(hepevt_.IDHEP[nn]);
  hlo.PHEP_X[nn] =hepevt_.PHEP[nn][0];
  hlo.PHEP_Y[nn] =hepevt_.PHEP[nn][1];
  hlo.PHEP_Z[nn] =hepevt_.PHEP[nn][2];
  hlo.PHEP_E[nn] =hepevt_.PHEP[nn][3];
  hlo.PHEP_M[nn] =hepevt_.PHEP[nn][4];
  hlo.VHEP_X[nn] =hepevt_.VHEP[nn][0];
  hlo.VHEP_Y[nn] =hepevt_.VHEP[nn][1];
  hlo.VHEP_Z[nn] =hepevt_.VHEP[nn][2];
  hlo.VHEP_T[nn] =hepevt_.VHEP[nn][3]; } 
  return 0;
}

//------------------------------ RunMC type of HEPEVT 
// mode = 1 all stable particle
// mode = 2 partons
// mode = 3 all HEPEVT
// mode = 4 all stable charged
Int_t hepevt_runmc( Int_t mode ) {

  extern hepenvtcommon hepevt_ ; // To access the external HEPEVT

       Int_t ntot=0; rlo.NHEP=0; 
       Int_t cha3; Int_t istcha3;     

  
       for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {


// get charge
       cha3=charge3(hepevt_.IDHEP[nn]);
       istcha3=100*hepevt_.ISTHEP[nn]+10+cha3;

// all particles
        if ( mode == 3 ) {  
           rlo.IDHEP[ntot]=hepevt_.IDHEP[nn];
           rlo.ISTCHA[ntot]=istcha3;
           rlo.JMOHEP[ntot]=hepevt_.JMOHEP[nn][0];
           rlo.JDAHEP[ntot]=hepevt_.JDAHEP[nn][0];
           rlo.PHEP_X[ntot] =(float)hepevt_.PHEP[nn][0];
           rlo.PHEP_Y[ntot] =(float)hepevt_.PHEP[nn][1];
           rlo.PHEP_Z[ntot] =(float)hepevt_.PHEP[nn][2];
           rlo.PHEP_E[ntot] =(float)hepevt_.PHEP[nn][3];  ntot++; } // end all particles
 
// stable particles  
        if ( mode == 1 && 
           hepevt_.ISTHEP[nn] == 1 &&  
           abs(hepevt_.IDHEP[nn]) != 12 &&
           abs(hepevt_.IDHEP[nn]) != 14 &&
           abs(hepevt_.IDHEP[nn]) != 16 &&
           abs(hepevt_.IDHEP[nn]) != 18 ) { 
           rlo.IDHEP[ntot]=hepevt_.IDHEP[nn];
           rlo.ISTCHA[ntot]=istcha3;
           rlo.JMOHEP[ntot]=hepevt_.JMOHEP[nn][0];
           rlo.JDAHEP[ntot]=hepevt_.JDAHEP[nn][0];
           rlo.PHEP_X[ntot] =(float)hepevt_.PHEP[nn][0];
           rlo.PHEP_Y[ntot] =(float)hepevt_.PHEP[nn][1];
           rlo.PHEP_Z[ntot] =(float)hepevt_.PHEP[nn][2];
           rlo.PHEP_E[ntot] =(float)hepevt_.PHEP[nn][3];  ntot++; } // end stable particles 


// stable charged particles 
        if ( mode == 4 &&
           hepevt_.ISTHEP[nn] == 1 &&
           abs(hepevt_.IDHEP[nn]) != 12 &&
           abs(hepevt_.IDHEP[nn]) != 14 &&
           abs(hepevt_.IDHEP[nn]) != 16 &&
           abs(hepevt_.IDHEP[nn]) != 18 && 
           abs( charge3(hepevt_.IDHEP[nn]) ) > 0)   { 
           rlo.IDHEP[ntot]=hepevt_.IDHEP[nn];
           rlo.ISTCHA[ntot]=istcha3;
           rlo.JMOHEP[ntot]=hepevt_.JMOHEP[nn][0];
           rlo.JDAHEP[ntot]=hepevt_.JDAHEP[nn][0];
           rlo.PHEP_X[ntot] =(float)hepevt_.PHEP[nn][0];
           rlo.PHEP_Y[ntot] =(float)hepevt_.PHEP[nn][1];
           rlo.PHEP_Z[ntot] =(float)hepevt_.PHEP[nn][2];
           rlo.PHEP_E[ntot] =(float)hepevt_.PHEP[nn][3];  ntot++; } // end charged stable particles



        if ( mode == 2 && 
          abs(hepevt_.IDHEP[nn]) < 7      ||  // quarks
          abs(hepevt_.IDHEP[nn]) == 21    ||  // gluons
          abs(hepevt_.IDHEP[nn]) == 2101  ||  // diquarks
          abs(hepevt_.IDHEP[nn]) == 3101  ||
          abs(hepevt_.IDHEP[nn]) == 3201  ||
          abs(hepevt_.IDHEP[nn]) == 1103  ||
          abs(hepevt_.IDHEP[nn]) == 2103  ||
          abs(hepevt_.IDHEP[nn]) == 3103  ||
          abs(hepevt_.IDHEP[nn]) == 3203  ||
          abs(hepevt_.IDHEP[nn]) == 3303  ) {
           rlo.IDHEP[ntot]=hepevt_.IDHEP[nn];
           rlo.ISTCHA[ntot]=istcha3;
           rlo.JMOHEP[ntot]=hepevt_.JMOHEP[nn][0];
           rlo.JDAHEP[ntot]=hepevt_.JDAHEP[nn][0];
           rlo.PHEP_X[ntot] =(float)hepevt_.PHEP[nn][0];
           rlo.PHEP_Y[ntot] =(float)hepevt_.PHEP[nn][1];
           rlo.PHEP_Z[ntot] =(float)hepevt_.PHEP[nn][2];
           rlo.PHEP_E[ntot] =(float)hepevt_.PHEP[nn][3];  ntot++; } // end charged stable particles


        } // end loop

         if (ntot == 0) { return 1; }

         rlo.NHEP =ntot;

 return 0;
}








//-------------------bst_fill.cpp HEPLIST CLASS definitions -----------------------------


// destructor
heplist::~heplist() { } 

// constructor
heplist::heplist() { }


// ----------------------- Fill all hadrons 
void heplist::fill_All() {

   extern hepenvtcommon hepevt_ ; // To access the external HEPEVT

// temporary staff
   particle xx;
   HepLorentzVector PXX;

// set vectors to zero
   PP.clear();
   Etot=0.;
   PZtot=0.;
   PTtot=0.;
   beam1.set(0.,0.,0.,0.); 
   beam2.set(0.,0.,0.,0.); 
   lepton.set(0.,0.,0.,0.); 
   boson.set(0.,0.,0.,0.);

// find out - is this DIS mode ?
   Int_t iEP=0;
   Int_t icc=0;
   Int_t ibb=0;
   if(abs(inival.IDparticle1) < 17 && abs(inival.IDparticle2) > 2000) { iEP=1;}
   if(abs(inival.IDparticle2) < 17 && abs(inival.IDparticle1) > 2000) { iEP=1;}

 
// loop over particles in this event
   for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {

   if (nn == 0 ) { id1=hepevt_.IDHEP[nn];
   beam1.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
   if (nn == 1 ){  id2=hepevt_.IDHEP[nn];
   beam2.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
// take exchange boson
   if (nn > 1 && ibb == 0 && abs(hepevt_.IDHEP[nn])>21 && abs(hepevt_.IDHEP[nn]) < 25 ) {
   idboson=hepevt_.IDHEP[nn];
   boson.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); ibb++; };

// take electron for DIS
   if (iEP ==1 && abs(hepevt_.IDHEP[nn]) < 17  && nn > 1 &&
   hepevt_.ISTHEP[nn] == 1 && icc == 0)   { // get DIS electron
   lepton.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
   icc++;
      //cout << nn << "Electron " << hepevt_.IDHEP[nn] << " " << hepevt_.PHEP[nn][3] <<  endl;
     continue; }


    PXX.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); 
    xx.p=PXX; 
    PXX.set(hepevt_.VHEP[nn][0],hepevt_.VHEP[nn][1],hepevt_.VHEP[nn][2],hepevt_.VHEP[nn][3]);
    xx.v=PXX;
    xx.mass=hepevt_.PHEP[nn][4];
    xx.pos =hepevt_.ISTHEP[nn];
    xx.id=hepevt_.IDHEP[nn];
    xx.charge3=charge3(hepevt_.IDHEP[nn]);
    xx.mother=hepevt_.JMOHEP[nn][0];
    xx.mother2=hepevt_.JMOHEP[nn][1];
    xx.daughter=hepevt_.JDAHEP[nn][0];
    xx.daughter2=hepevt_.JDAHEP[nn][1];
    PP.push_back( xx );
   
   Etot=Etot+ hepevt_.PHEP[nn][3];
   PZtot=PZtot+ hepevt_.PHEP[nn][2];
   PTtot=PTtot+sqrt(hepevt_.PHEP[nn][0]*hepevt_.PHEP[nn][0]+hepevt_.PHEP[nn][1]*hepevt_.PHEP[nn][1]);
            };      // end of the loop over tracks

};




// ----------------------- Fill all HEPEVT record
void heplist::fill_HEPEVT() {
 
   extern hepenvtcommon hepevt_ ; // To access the external HEPEVT
 
   // temporary staff
   particle xxx;
   HepLorentzVector PXXX;
 
// set vectors to zero
   HP.clear();
// loop over particles in this event
   for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {
    PXXX.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
    xxx.p=PXXX;
    PXXX.set(hepevt_.VHEP[nn][0],hepevt_.VHEP[nn][1],hepevt_.VHEP[nn][2],hepevt_.VHEP[nn][3]);
    xxx.v=PXXX;
    xxx.mass=hepevt_.PHEP[nn][4];
    xxx.pos =hepevt_.ISTHEP[nn];
    xxx.id=hepevt_.IDHEP[nn];
    xxx.charge3=charge3(hepevt_.IDHEP[nn]);
    xxx.mother=hepevt_.JMOHEP[nn][0];
    xxx.mother2=hepevt_.JMOHEP[nn][1];
    xxx.daughter=hepevt_.JDAHEP[nn][0];
    xxx.daughter2=hepevt_.JDAHEP[nn][1];
    HP.push_back( xxx );
   }


} // end fill_HEPEVT()



// ----------------------- Fill stable hadrons (without neutrinos) 
void heplist::fill_ALLstable() {

   extern hepenvtcommon hepevt_ ; // To access the external HEPEVT

   // temporary staff
   particle xx;
   HepLorentzVector PXX;

// set vectors to zero
   PP.clear();
   Etot=0.;
   PZtot=0.;
   PTtot=0.;
   beam1.set(0.,0.,0.,0.);
   beam2.set(0.,0.,0.,0.);
   lepton.set(0.,0.,0.,0.);
   boson.set(0.,0.,0.,0.);

// find out - is this DIS mode ?
   Int_t iEP=0;     
   Int_t icc=0; 
   Int_t ibb=0; 
   if(abs(inival.IDparticle1) < 17 && abs(inival.IDparticle2) > 2000) { iEP=1;}
   if(abs(inival.IDparticle2) < 17 && abs(inival.IDparticle1) > 2000) { iEP=1;}

// loop over particles in this event
   for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {

   if (nn == 0 ) { id1=hepevt_.IDHEP[nn];
   beam1.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
   if (nn == 1 ){  id2=hepevt_.IDHEP[nn];
   beam2.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };

// take exchange boson 
   if (nn > 1 && ibb == 0 && abs(hepevt_.IDHEP[nn])>21 && abs(hepevt_.IDHEP[nn]) < 25 ) {  
   idboson=hepevt_.IDHEP[nn];
   boson.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); ibb++; };


    if (iEP ==1 && abs(hepevt_.IDHEP[nn]) < 17  && nn > 1 && 
    hepevt_.ISTHEP[nn] == 1 && icc == 0)   { // get DIS electron  
    lepton.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
    icc++;
  //  cout << nn << " Electron " << hepevt_.IDHEP[nn] << " " << hepevt_.PHEP[nn][3] << endl; 
    continue; } 

//      cout << nn << " " << hepevt_.IDHEP[nn] << " " << hepevt_.PHEP[nn][1] <<  endl;
// final states
        if (hepevt_.ISTHEP[nn] == 1 &&
            abs(hepevt_.IDHEP[nn]) != 12 &&
            abs(hepevt_.IDHEP[nn]) != 14 &&  
            abs(hepevt_.IDHEP[nn]) != 16 &&
            abs(hepevt_.IDHEP[nn]) != 17 
            ) {
   
    PXX.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
    xx.p=PXX;
    PXX.set(hepevt_.VHEP[nn][0],hepevt_.VHEP[nn][1],hepevt_.VHEP[nn][2],hepevt_.VHEP[nn][3]);
    xx.v=PXX;
    xx.mass=hepevt_.PHEP[nn][4];
    xx.pos =hepevt_.ISTHEP[nn];
    xx.id=hepevt_.IDHEP[nn];
    xx.charge3=charge3(hepevt_.IDHEP[nn]);
    xx.mother=hepevt_.JMOHEP[nn][0];
    xx.mother2=hepevt_.JMOHEP[nn][1];
    xx.daughter=hepevt_.JDAHEP[nn][0];
    xx.daughter2=hepevt_.JDAHEP[nn][1];
    PP.push_back( xx );
    Etot=Etot+ hepevt_.PHEP[nn][3];
    PZtot=PZtot+ hepevt_.PHEP[nn][2];
    PTtot=PTtot+
    sqrt(hepevt_.PHEP[nn][0]*hepevt_.PHEP[nn][0]+hepevt_.PHEP[nn][1]*hepevt_.PHEP[nn][1]);
    };  };      // end of the loop over tracks

             Etot=Etot+lepton[3];
             PZtot=PZtot+lepton[2];
             PTtot=PTtot+lepton.perp(); 
};

// Charged stable particles 
void heplist::fill_CHARGEDstable() {

   extern hepenvtcommon hepevt_ ; // To access the external HEPEVT

// temporary staff
   particle xx;
   HepLorentzVector PXX;

// set vectors to zero
   PP.clear();
   Etot=0.;
   PZtot=0.;
   PTtot=0.;
   beam1.set(0.,0.,0.,0.);
   beam2.set(0.,0.,0.,0.);
   lepton.set(0.,0.,0.,0.);
   boson.set(0.,0.,0.,0.);


// find out - is this DIS mode ?
   Int_t iEP=0;
   Int_t icc=0, ibb=0;
   if(abs(inival.IDparticle1) < 17 && abs(inival.IDparticle2) > 2000) { iEP=1;}
   if(abs(inival.IDparticle2) < 17 && abs(inival.IDparticle1) > 2000) { iEP=1;}

// loop over particles in this event
   for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {

   if (nn == 0 ) { id1=hepevt_.IDHEP[nn];
   beam1.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
   if (nn == 1 ){  id2=hepevt_.IDHEP[nn];
   beam2.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
// take exchange boson
   if (nn > 1 && ibb == 0 && abs(hepevt_.IDHEP[nn])>21 && abs(hepevt_.IDHEP[nn]) < 25 ) {
   idboson=hepevt_.IDHEP[nn];
   boson.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); ibb++; };


   if (iEP ==1 && abs(hepevt_.IDHEP[nn]) < 17  && nn > 1 && 
      hepevt_.ISTHEP[nn] == 1 && icc == 0)   { // get DIS electron
      lepton.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
      icc++;
      //cout << nn << "Electron " << hepevt_.IDHEP[nn] << " " << hepevt_.PHEP[nn][3] <<  endl;
     continue; }

// final states
        if (hepevt_.ISTHEP[nn] == 1 &&
            abs(hepevt_.IDHEP[nn]) != 12 &&
            abs(hepevt_.IDHEP[nn]) != 14 &&
            abs(hepevt_.IDHEP[nn]) != 16 &&
            abs(hepevt_.IDHEP[nn]) != 17 ) {   
            if (abs( charge3(hepevt_.IDHEP[nn]) ) > 0) { 

    PXX.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
    xx.p=PXX;
    PXX.set(hepevt_.VHEP[nn][0],hepevt_.VHEP[nn][1],hepevt_.VHEP[nn][2],hepevt_.VHEP[nn][3]);
    xx.v=PXX;
    xx.mass=hepevt_.PHEP[nn][4];
    xx.pos =hepevt_.ISTHEP[nn];
    xx.id=hepevt_.IDHEP[nn];
    xx.charge3=charge3(hepevt_.IDHEP[nn]);
    xx.mother=hepevt_.JMOHEP[nn][0];
    xx.mother2=hepevt_.JMOHEP[nn][1];
    xx.daughter=hepevt_.JDAHEP[nn][0];
    xx.daughter2=hepevt_.JDAHEP[nn][1];
    PP.push_back( xx );

      Etot=Etot+ hepevt_.PHEP[nn][3];
      PZtot=PZtot+ hepevt_.PHEP[nn][2];
      PTtot=PTtot+
      sqrt(hepevt_.PHEP[nn][0]*hepevt_.PHEP[nn][0]+hepevt_.PHEP[nn][1]*hepevt_.PHEP[nn][1]);
       }; }; // end if if 
       };      // end of the loop over tracks

// get sizes of vectors
             Etot=Etot+lepton[3];
             PZtot=PZtot+lepton[2];
             PTtot=PTtot+lepton.perp();


};



// ----------------------- Fill partons 
void heplist::fill_Partons() {

   extern hepenvtcommon hepevt_ ; // To access the external HEPEVT

// temporary staff
   particle xx;
   HepLorentzVector PXX;


// set vectors to zero
   PP.clear();
   Etot=0.;
   PZtot=0.;
   PTtot=0.;
   beam1.set(0.,0.,0.,0.);
   beam2.set (0.,0.,0.,0.);
   lepton.set(0.,0.,0.,0.);
   boson.set(0.,0.,0.,0.);

// find out - is this DIS mode ?
   Int_t iEP=0;
   Int_t icc=0, ibb=0;
   if(abs(inival.IDparticle1) < 17 && abs(inival.IDparticle2) > 2000) { iEP=1;}
   if(abs(inival.IDparticle2) < 17 && abs(inival.IDparticle1) > 2000) { iEP=1;}


// loop over particles in this event
   for (Int_t nn=0; nn < hepevt_.NHEP; nn++) {

// take beam
   if (nn == 0 ) { id1=hepevt_.IDHEP[nn];
   beam1.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
   if (nn == 1 ){  id2=hepevt_.IDHEP[nn];
   beam2.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); };
// take exchange boson
   if (nn > 1 && ibb == 0 && abs(hepevt_.IDHEP[nn])>21 && abs(hepevt_.IDHEP[nn]) < 25 ) {
   idboson=hepevt_.IDHEP[nn];
   boson.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]); ibb++; };


   if (iEP ==1 && abs(hepevt_.IDHEP[nn]) < 17  && nn > 1 && 
   hepevt_.ISTHEP[nn] == 1 && icc == 0)   { // get DIS electron
   lepton.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
   icc++;
      //cout << nn << "Electron " << hepevt_.IDHEP[nn] << " " << hepevt_.PHEP[nn][3] <<  endl;
     continue; }

            if (
               hepevt_.ISTHEP[nn] == 2        && // partons before hadronization      
               (abs(hepevt_.IDHEP[nn]) < 7     ||  // quarks
               abs(hepevt_.IDHEP[nn]) == 21    ||  // gluons 
               abs(hepevt_.IDHEP[nn]) == 2101  ||  // diquarks 
               abs(hepevt_.IDHEP[nn]) == 3101  ||
               abs(hepevt_.IDHEP[nn]) == 3201  ||
               abs(hepevt_.IDHEP[nn]) == 1103  ||
               abs(hepevt_.IDHEP[nn]) == 2103  ||
               abs(hepevt_.IDHEP[nn]) == 3103  ||
               abs(hepevt_.IDHEP[nn]) == 3203  ||
               abs(hepevt_.IDHEP[nn]) == 3303)     ) {  

    PXX.set(hepevt_.PHEP[nn][0],hepevt_.PHEP[nn][1],hepevt_.PHEP[nn][2],hepevt_.PHEP[nn][3]);
    xx.p=PXX;
    PXX.set(hepevt_.VHEP[nn][0],hepevt_.VHEP[nn][1],hepevt_.VHEP[nn][2],hepevt_.VHEP[nn][3]);
    xx.v=PXX;
    xx.mass=hepevt_.PHEP[nn][4];
    xx.pos =hepevt_.ISTHEP[nn];
    xx.id=hepevt_.IDHEP[nn];
    xx.charge3=charge3(hepevt_.IDHEP[nn]);
    xx.mother=hepevt_.JMOHEP[nn][0];
    xx.mother2=hepevt_.JMOHEP[nn][1]; 
    xx.daughter=hepevt_.JDAHEP[nn][0];
    xx.daughter2=hepevt_.JDAHEP[nn][1];
    PP.push_back( xx );


      Etot=Etot+ hepevt_.PHEP[nn][3];
      PZtot=PZtot+ hepevt_.PHEP[nn][2];
      PTtot=PTtot+
      sqrt(hepevt_.PHEP[nn][0]*hepevt_.PHEP[nn][0]+hepevt_.PHEP[nn][1]*hepevt_.PHEP[nn][1]);
       };   };      // end of the loop over tracks

// get sizes of vectors
             Etot=Etot+lepton[3];
             PZtot=PZtot+lepton[2];
             PTtot=PTtot+lepton.perp();

};
