// * Copyright (C) 2002-2004 Sergei Chekanov (ANL) chekanov@mail.desy.de 
// * This file is part of the RunMC project
// * 
// * Permission is hereby granted, free of charge, to any person obtaining a copy
// * of this software and associated documentation files (the "Software"), to
// * deal in the Software without restriction, including without limitation the
// * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// * sell copies of the Software, and to permit persons to whom the Software is
// * furnished to do so, subject to the following conditions:
// *
// * The above copyright notice and this permission notice shall be included in
// * all copies or substantial portions of the Software.
// * 
// * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// * SERGEI  CHEKANOV BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// * OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// * SOFTWARE.
// * 
// * Except as contained in this notice, the name of Sergei Chekanov shall
// * not be used in advertising or otherwise to promote the sale, use or other
// * dealings in this Software without prior written authorization from
// * Sergei Chekanov.
// * 
// get all calculated value into the histogram
using namespace std;
#include<iostream>
#include<math.h>
#include<TMath.h>
#include<heplist.h>
#include<SetIni.h>   // include class containing initializations for MC

#include <myroot.h>   // Root include 
#include <TMath.h>
#include <TVector3.h>
#include <TLorentzVector.h>
#include <TRotation.h>
#include <TLorentzRotation.h>
#include <TObjArray.h>
#include <JetFinder.h>

/** Need to include these KtJet Headers */
#include "KtJet/KtEvent.h"
#include "KtJet/KtLorentzVector.h"
#include "KtJet/KtJet.h"

// CLHEP 
#include "CLHEP/Vector/Boost.h"
#include "CLHEP/Vector/Rotation.h"
#include "CLHEP/Units/PhysicalConstants.h"

extern SetIni inival;


// ----------------------- Set cuts on separate particles 
Int_t heplist::set_particlePtEta() {



// if zero and negartive: do not do anything
   if (inival.ETmin <=  0.0 ) return 0;

   Etot=0.; 
   PZtot=0.;
   PTtot=0.;   

// set vectors to zero
   double et=0.;
   double pz=0.;
   double pt=0.;  
   double eta=-1000000.;

   vector<particle>  PPC;            // temporary vector with particles after cuts 
   unsigned int VMAX=PP.size();
// cout << "VMAX " << VMAX << endl;

   for  (unsigned int n=0; n<VMAX; n++ ) {

   if (PP[n].p.perp() > 0.0000001) eta=PP[n].p.pseudoRapidity();  
//  cout  << n << "  " << FinalState.Id[n] << " " << eta << "  " << ptt << endl;

          if (PP[n].p.perp() > inival.ETmin  &&  
                    eta > inival.ETAmin && eta < inival.ETAmax )   { 
           PPC.push_back( PP[n] );  
           et=et+PP[n].p.e();
           pz=pz+PP[n].p.pz();
           pt=pt+PP[n].p.perp(); 
         };       // end if 
         };      // end of the loop over tracks
         Etot=et; PZtot=pz; PTtot=pt;

// copy back 
         PP=PPC;

//       cout << "VMAX after" << PP.size() << endl;
//       vector<HepLorentzVector>::PP.erase(PPmin,PPmax);
//       cout << "VMAX after erase" << PP.size() << endl; 


return 0;
};



// ----------------------- Set cuts on Jets 
Int_t heplist::set_jetPtEta() {


// if zero and negartive: do not do anything
   if (inival.ETmin <=  0.0 ) return 0;


   double eta=-999999.; 
   vector<jet>  PJC;            // temporary vector with jet after cuts


   unsigned int VMAX=PJ.size();

   for (unsigned int n=0; n<VMAX; n++ ) {

   if (PJ[n].p.perp() > 0.0000001) eta=PJ[n].p.pseudoRapidity();
// cout  << n << "  " << FinalState.Id[n] << " " << eta << "  " << ptt << endl;

          if (PJ[n].p.perp() > inival.ETmin  &&
                    eta > inival.ETAmin && eta < inival.ETAmax )   {
           PJC.push_back( PJ[n] );
           }; // end if
           };      // end of the loop over tracks

// copy back 
      PJ=PJC;


return 0;
}; // end set_PtEtaJets() 



// ----------------------- Move particles to Breit frame
Int_t heplist::set_particleLABtoBREITframe() {

   HepLorentzVector plep, phad;

// find out - is this DIS mode ?
   Int_t iEP=0;
   if(abs(id1) < 17 && abs(id2) > 2000) { iEP=1;}
   if(abs(id2) < 17 && abs(id1) > 2000) { iEP=1;}
   if (inival.Q2min < 1.0) iEP=0;
   if (iEP == 0) { return 1; };

// set beams 
  if (abs(id1) > 2000) {phad=beam1; plep=beam2;}; 
  if (abs(id1) < 20)   {plep=beam1; phad=beam2;}; 


    if (boson.mag2() >= 0.) { return 2;}
    double xb = -0.5*boson.mag2()/(phad*boson);
    Hep3Vector bVec = -((boson + 2.0*xb*phad).boostVector());


   phad.boost(bVec);
   for (unsigned int n=0; n<PP.size(); n++ ) PP[n].p.boost(bVec); 

    double phi = phad.phi(), theta = phad.theta();
    phad.rotateZ(-phi);
    phad.rotateY(-theta);

     for (unsigned int n=0; n<PP.size(); n++ ) {
      PP[n].p.rotateZ(-phi);
      PP[n].p.rotateY(-theta);
     };


return 0;
};



// ----------------------- Move to frame
Int_t heplist::set_jetLABtoBREITframe() {

    HepLorentzVector plep, phad;

// find out - is this DIS mode ?
   Int_t iEP=0;
   if(abs(id1) < 17 && abs(id2) > 2000) { iEP=1;}
   if(abs(id2) < 17 && abs(id1) > 2000) { iEP=1;}
   if (inival.Q2min < 1.0) iEP=0;
   if (iEP == 0) { return 1; };

// set beams 
  if (abs(id1) > 2000) {phad=beam1; plep=beam2;};
  if (abs(id1) < 20)   {plep=beam1; phad=beam2;};


     if (boson.mag2() >= 0.) { return 2;}  
     double xb = -0.5*boson.mag2()/(phad*boson);
     Hep3Vector bVec = -((boson + 2.0*xb*phad).boostVector());

     phad.boost(bVec);

     for (unsigned int n=0; n<PJ.size(); n++ ) {
     PJ[n].p.boost(bVec);
     };

     double phi = phad.phi(), theta = phad.theta();

    phad.rotateZ(-phi);
    phad.rotateY(-theta);

     for (unsigned int n=0; n<PJ.size(); n++ ) {
      PJ[n].p.rotateZ(-phi);
      PJ[n].p.rotateY(-theta);
     };

//      double xb = -1*boson.mag2()/ 2. /(boson[3]*boson[3]-boson[2]*boson[2]);
//      if (xb > 1. || xb < 0.) { return 3; }
 
return 0;
};



// ----------------------- Move to frame
Int_t heplist::set_particleLABtoHCMframe() {

   HepLorentzVector plep, phad;

// find out - is this DIS mode ?
  Int_t iEP=0;
  if(abs(id1) < 17 && abs(id2) > 2000) { iEP=1;}
  if(abs(id2) < 17 && abs(id1) > 2000) { iEP=1;}
  if (inival.Q2min < 1.0) iEP=0;
  if (iEP == 0) { return 1; };
// set beams
  if (abs(id1) > 2000) {phad=beam1; plep=beam2;};
  if (abs(id1) < 20)   {plep=beam1; phad=beam2;};

   double tmp=1./ (boson.e()+phad.e());
   Hep3Vector bVec = -tmp*( (boson + phad).boostVector() );
   boson.boost(bVec);

    for (unsigned int n=0; n<PP.size(); n++ ) PP[n].p.boost(bVec);  
    double phi = boson.phi(), theta = boson.theta();

    for (unsigned int n=0; n<PP.size(); n++ ) {
      PP[n].p.rotateZ(-phi);
      PP[n].p.rotateY(-theta);
     };
//      double xb = -1*boson.mag2()/ 2. /(boson[3]*boson[3]-boson[2]*boson[2]);
//      if (xb > 1. || xb < 0.) { return 3; }

return 0;
};

// ----------------------- Move to frame
Int_t heplist::set_jetLABtoHCMframe() {

   HepLorentzVector plep, phad;

// find out - is this DIS mode ?
   Int_t iEP=0;
   if(abs(id1) < 17 && abs(id2) > 2000) { iEP=1;}
   if(abs(id2) < 17 && abs(id1) > 2000) { iEP=1;}
   if (inival.Q2min < 1.0) iEP=0;
   if (iEP == 0) { return 1; };
// set beams
  if (abs(id1) > 2000) {phad=beam1; plep=beam2;};
  if (abs(id1) < 20)   {plep=beam1; phad=beam2;};

    double tmp=1./ (boson.e()+phad.e());
     Hep3Vector bVec = -tmp*( (boson + phad).boostVector() );
     boson.boost(bVec);
     for (unsigned int n=0; n<PJ.size(); n++ ) PJ[n].p.boost(bVec); 
     double phi = boson.phi(), theta = boson.theta();

    for (unsigned int n=0; n<PJ.size(); n++ ) {
      PJ[n].p.rotateZ(-phi);
      PJ[n].p.rotateY(-theta);
     };
//      double xb = -1*boson.mag2()/ 2. /(boson[3]*boson[3]-boson[2]*boson[2]);
//      if (xb > 1. || xb < 0.) { return 3; }

return 0;
};



// ----------------------- Move to JADE jets
Int_t  heplist::set_JADEjets() {

// temporary class
   jet jj; 

// set to 0 
   PJ.clear();

// set Ycut 
     double ycut=inival.JetYcut;
//   Make particle 4-vector list
     TObjArray* veclist = new TObjArray();
//  Clean up veclist
     veclist->Delete();
     for (unsigned int n=0; n<PP.size(); n++ ) { 
         TLorentzVector* p = new TLorentzVector();
         p->SetPxPyPzE(PP[n].p.px(), PP[n].p.py(), PP[n].p.pz(), PP[n].p.e());
         veclist->Add(p);  // Fill particle 4-vector list.
     };      // end of the loop over tracks
//   Set up the JetFinder
    JetFinder  jetf;

    jetf.setPartList(veclist); // Input particle 4-vector list
    jetf.setJADE();            // Use JADE algorithm
    jetf.setYCut( ycut );      // Y cut 
    jetf.doFindJets();         // JetFindig

    HepLorentzVector PXX;

   for  (Int_t n=0; n<jetf.njets(); n++ ) {
      TLorentzVector* pj = jetf.jet4vec( n );
//            cout << n << " " << pj->Px() << endl;
      PXX.set( pj->Px() , pj->Py(), pj->Pz(), pj->E() );
// move to vector 
      jj.p=PXX;
      jj.in=0; 
      PJ.push_back(jj);
    };      //

//    cout << NJtot << endl;
//     Ntot=numjets;


return 0;
};

// ----------------------- Move to jets
Int_t heplist::set_DURHAMjets() {


// temporary
   jet jj;

// set to 0
   PJ.clear();

// set Ycut
     double ycut=inival.JetYcut;
//   Make particle 4-vector list
     TObjArray* veclist = new TObjArray();
//  Clean up veclist
     veclist->Delete();
     for (unsigned int n=0; n<PP.size(); n++ ) {
         TLorentzVector* p = new TLorentzVector();
         p->SetPxPyPzE( PP[n].p.px(), PP[n].p.py(), PP[n].p.pz(), PP[n].p.e() );
         veclist->Add(p);  // Fill particle 4-vector list.
     };      // end of the loop over tracks

//   Set up the JetFinder
    JetFinder  jetf;
    jetf.setPartList(veclist); // Input particle 4-vector list
    jetf.setDURHAM();;         // Use DURHAM algorithm
    jetf.setYCut( ycut );      // Y cut
    jetf.doFindJets();         // JetFindig

      HepLorentzVector PXX;

      for (Int_t n=0; n<jetf.njets(); n++ ) { 
      TLorentzVector* pj = jetf.jet4vec( n );
      PXX.set( pj->Px() , pj->Py(), pj->Pz(), pj->E() );  
// move to vector
      jj.p=PXX;
      jj.in=0;
      PJ.push_back(jj);
    };      //

return 0;
};

// ----------------------- Move to jets
Int_t heplist::set_KTjets() {


   jet jj;

// set to 0
   PJ.clear();
   HepLorentzVector PXX;

   Int_t kttype=0;
// DIS 
   if(abs(inival.IDparticle1) < 17 && abs(inival.IDparticle2) > 2000) { kttype=2;}//ep 
   if(abs(inival.IDparticle2) < 17 && abs(inival.IDparticle1) > 2000) { kttype=3;} //pe 
// e+e-
   if(abs(inival.IDparticle1) < 17 && abs(inival.IDparticle2) < 17)   { kttype=1;} 
   if(abs(inival.IDparticle2) < 17 && abs(inival.IDparticle1) < 17)   { kttype=1;}
// e+e-
   if(abs(inival.IDparticle1) > 2000 && abs(inival.IDparticle2) > 2000)  { kttype=4;}
   if(abs(inival.IDparticle2) > 2000 && abs(inival.IDparticle1) > 2000)  { kttype=4;}


 /** Make a std::vector of KtJet::KtLorentzVectors which will be the
      input particles */
  std::vector<KtJet::KtLorentzVector> avec;
  /** read in 4-vectors and fill std::vector */

     for  (unsigned int n=0; n<PP.size(); n++ ) {
         KtJet::KtLorentzVector jeves(PP[n].p.px(), PP[n].p.py(), PP[n].p.pz(), PP[n].p.e());
         avec.push_back( jeves );
     };      // end of the loop over tracks

// set KtEvent flags 
  Int_t angle = inival.JetAngle; //Angular
  Int_t recom = inival.JetRecomb; // E
  double rparameter = 1.0;

  KtJet::KtEvent ev(avec,kttype,angle,recom,rparameter);

  if (kttype == 1 )  {  
       Int_t nfixed = inival.JetNfixed;
       if (nfixed > 0 ) ev.findJetsN( nfixed );
   }

//  Retrieve the final state jets from KtEvent sorted by Et
  vector<KtJet::KtLorentzVector> jets = ev.getJetsEt();

// Print out jets 4-momentum and Pt 
  Int_t nn=0;
  vector<KtJet::KtLorentzVector>::const_iterator itr = jets.begin();
  for( ; itr != jets.end() ; ++itr) {
//    cout << "Jets 4 vector: "
//              << (*itr).px() << " "
//              << (*itr).py() << " "
//              << (*itr).pz() << " "
//              << (*itr).e() << std::endl;
               nn++; 
               PXX.set( (*itr).px(), (*itr).py(), (*itr).pz(), (*itr).e() );
// move to vector
      jj.p=PXX;
      jj.in=0;
      PJ.push_back(jj);
//    cout << "Jets Pt: " << (*itr).perp() << std::endl;
  };


return 0;
}; 
